@@ -10,7 +10,7 @@ import os
 from subprocess import Popen, PIPE
 from dataclasses import dataclass
 
-__version__ = "0.2.9"
+__version__ = "0.2.10"
 
 
 
@@ -26,8 +26,7 @@ class PythonInfo:
 
 
 def get_python_version(py_path):
-    """
-    Return Python version.
+    """Return Python version.
     """
     res = Popen(
         [py_path, "-V"],
@@ -40,12 +39,10 @@ def get_python_version(py_path):
 
 
 def get_python_installs():
-    """
-    Get the available python versions installed.
-    """
+    """Write the found Python versions to `py-installs` csv file."""
     versions = ["3.9", "3.8", "3.7", "3.6", "3.5", "3.4", "3.3"]
-    py_info_list = []
     csv_file = os.path.expanduser("~/.venvipy/py-installs")
+    py_info_list = []
 
     if not os.path.exists(os.path.expanduser("~/.venvipy")):
         os.mkdir(os.path.expanduser("~/.venvipy"))
@@ -71,8 +68,8 @@ def get_python_installs():
 
 def add_sys_python():
     """
-    Add the system python if running VenviPy in a
-    virtual environment.
+    Write the the system Python's version and path to `py-installs`
+    csv file if running VenviPy in a virtual environment.
     """
     csv_file = os.path.expanduser("~/.venvipy/py-installs")
     super_python = os.path.realpath(sys.executable)
@@ -100,8 +97,8 @@ class VenvInfo:
     """_"""
     venv_name: str
     venv_version: str
-    system_site_packages: str
-    is_on_system: str
+    site_packages: str
+    is_installed: str
 
 
 def get_venvs(path):
@@ -127,58 +124,65 @@ def get_venvs(path):
             continue
 
         venv_name = os.path.basename(valid_venv)
-        version_found = get_pyvenv_cfg(cfg_file, line=2)
-        system_site_packages = get_pyvenv_cfg(cfg_file, line=1)
-        is_on_system = is_installed(cfg_file)
+        venv_version = get_pyvenv_cfg(cfg_file, "version")
+        site_packages = get_pyvenv_cfg(cfg_file, "site_packages")
+        is_installed = get_pyvenv_cfg(cfg_file, "installed")
 
         venv_info = VenvInfo(
-            venv_name, version_found, system_site_packages, is_on_system
+            venv_name, venv_version, site_packages, is_installed
         )
         venv_info_list.append(venv_info)
 
     return venv_info_list
 
 
-def is_installed(cfg_file):
+def to_version(value):
+    """Convert a value to a readable version string."""
+    return f"Python {value}"
+
+
+def to_path(bin_path, version):
+    """Return the absolute path to a python binary."""
+    return os.path.join(bin_path, f"python{version}")
+
+
+def get_pyvenv_cfg(cfg_file, cfg):
     """
-    Check if a Python version is installed.
+    Return the values as string from a `pyvenv.cfg` file.
+    Values for `cfg` can be strings: `version`, `py_path`,
+    `site_packages` or `installed`.
     """
     with open(cfg_file, "r") as f:
         lines = f.readlines()
 
-    python_path = lines[0][7:].strip()  # e.g. /usr/local/bin
-    python_version = lines[2][10:13].strip()  # e.g. 3.8
-    target = f"{python_path}/python{python_version}"
+    version_str = to_version(lines[2][10:].strip())
+    binary_path = to_path(lines[0][7:].strip(), lines[2][10:13].strip())
+    site_packages = lines[1][31:].strip()
     csv_file = os.path.expanduser("~/.venvipy/py-installs")
 
-    if not os.path.isfile(csv_file):
-        get_python_installs()
+    if cfg == "version":
+        return version_str
 
-    with open(csv_file, newline="") as cf:
-        reader = csv.DictReader(cf, delimiter=",")
-        for info in reader:
-            if target == info["PYTHON_PATH"]:
-                return "yes"
-        return "no"
+    if cfg == "py_path":
+        return binary_path
 
-
-def get_pyvenv_cfg(cfg_file, line):
-    """
-    Get the required info of a virtual environment
-    by reading `pyvenv.cfg` file.
-    """
-    with open(cfg_file, "r") as f:
-        lines = f.readlines()
-
-    if line == 1:
-        system_site_packages = lines[1][31:]  # true | false
-        if "true" in system_site_packages:
+    if cfg == "site_packages":
+        if site_packages == "true":
             return "global"
-        if "false" in system_site_packages:
+        if site_packages == "false":
             return "isolated"
-    if line == 2:
-        python_version = lines[2][10:]  # e.g. 3.8.2
-        return f"Python {python_version}".strip()
+        return "N/A"
+
+    if cfg == "installed":
+        if not os.path.isfile(csv_file):
+            get_python_installs()
+        with open(csv_file, newline="") as cf:
+            reader = csv.DictReader(cf, delimiter=",")
+            for info in reader:
+                if binary_path == info["PYTHON_PATH"]:
+                    return "yes"
+            return "no"
+
     return "N/A"
 
 
@@ -216,66 +220,36 @@ def get_active_dir():
 #]===========================================================================[#
 
 @dataclass
-class ModuleInfo:
+class PackageInfo:
     """_"""
-    mod_name: str
-    mod_version: str
-    mod_summary: str
+    pkg_name: str
+    pkg_version: str
+    pkg_summary: str
 
 
-def get_module_infos(name):
+def get_package_infos(name):
     """
-    Get module name, version and description
+    Get the package's name, version and description
     from [PyPI](https://pypi.org/pypi).
     """
     client = xmlrpc.client.ServerProxy("https://pypi.org/pypi")
     search_result = client.search({"name": name})
 
-    module_info_list = []
+    package_info_list = []
 
-    for i, mod in enumerate(search_result):
-        mod_name = mod["name"]
-        mod_version = mod["version"]
-        mod_summary = mod["summary"]
+    for i, pkg in enumerate(search_result):
+        pkg_name = pkg["name"]
+        pkg_version = pkg["version"]
+        pkg_summary = pkg["summary"]
 
-        mod_info = ModuleInfo(mod_name, mod_version, mod_summary)
-        module_info_list.append(mod_info)
+        pkg_info = PackageInfo(pkg_name, pkg_version, pkg_summary)
+        package_info_list.append(pkg_info)
 
-    return module_info_list[::-1]
+    return package_info_list[::-1]
 
 
 
 if __name__ == "__main__":
-    #pass
+    pass
 
-    get_python_installs()
-
-
-    #]=======================================================================[#
-
-    #test_cfg_file = "/mnt/SQ-Core/coding/.virtualenvs/.OLD/pgsqltest/pyvenv.cfg"
-    #test_cfg_file = "/mnt/SQ-Core/coding/.virtualenvs/pyqt-dev-build/pyvenv.cfg"
-
-    #print(is_installed(test_cfg_file))
-
-    #]=======================================================================[#
-
-    #for python in get_python_installs():
-        #print(python.py_version, python.py_path)
-
-    #]=======================================================================[#
-
-    # venv in get_active_dir():
-        #print(venv.name, venv.version)
-
-    #]=======================================================================[#
-
-    #test_module = "test"
-
-    #for item in get_module_infos(test_mod):
-        #print(item.mod_name, item.mod_version, item.mod_summary)
-
-    #if not get_module_infos(test_module):
-        #print("No modules found!")
-
-    #print(get_active_dir())
+    #get_python_installs()
