@@ -5,6 +5,7 @@ The main module of VenviPy.
 import sys
 import os
 import csv
+import getopt
 from pathlib import Path
 
 # need to set the correct cwd
@@ -43,16 +44,12 @@ from PyQt5.QtWidgets import (
     QHBoxLayout,
     QLineEdit
 )
-import venvipy_rc  # pylint: disable=unused-import
 
-from get_data import (
-    get_active_dir,
-    get_active_dir_str,
-    get_python_installs
-)
+import venvipy_rc  # pylint: disable=unused-import
+import get_data
+import wizard
 from dialogs import InfoAboutVenviPy
 from tables import VenvTable
-import wizard
 
 
 
@@ -461,7 +458,8 @@ class MainWindow(QMainWindow):
 
 
     def info_about_qt(self):
-        """Open the "About Qt" dialog."""
+        """Open the "About Qt" dialog.
+        """
         QMessageBox.aboutQt(self)
 
 
@@ -476,7 +474,8 @@ class MainWindow(QMainWindow):
 
 
     def center(self):
-        """Center window."""
+        """Center window.
+        """
         qr = self.frameGeometry()
         cp = QDesktopWidget().availableGeometry().center()
         qr.moveCenter(cp)
@@ -484,8 +483,7 @@ class MainWindow(QMainWindow):
 
 
     def on_close(self):
-        """
-        Stop all threads, then close the application.
+        """Stop all threads, then close the application.
         """
         self.venv_wizard.basic_settings.thread.exit()
         self.venv_table.thread.exit()
@@ -493,8 +491,7 @@ class MainWindow(QMainWindow):
 
 
     def add_interpreter(self):
-        """
-        Add a custom interpreter.
+        """Add a custom interpreter.
         """
         if self.venv_wizard.basic_settings.select_python() != "":
             self.enable_features(True)
@@ -508,8 +505,7 @@ class MainWindow(QMainWindow):
 
     @pyqtSlot()
     def pop_interpreter_table(self):
-        """
-        Populate the interpreter table view.
+        """Populate the interpreter table view.
         """
         csv_file = os.path.expanduser("~/.venvipy/py-installs")
 
@@ -521,33 +517,27 @@ class MainWindow(QMainWindow):
                 for info in reader:
                     self.model_interpreter_table.insertRow(0)
                     for i, text in enumerate(
-                        (info["PYTHON_VERSION"], info["PYTHON_PATH"])
-                    ):
+                            (info["PYTHON_VERSION"], info["PYTHON_PATH"])
+                        ):
                         self.model_interpreter_table.setItem(
                             0, i, QStandardItem(text)
                         )
-                        #if sys.executable in info["PYTHON_PATH"]:
-                            #print(sys.executable)
-
-                    print(f"[PYTHON]: {info}")
 
 
     def pop_venv_table(self):
-        """
-        Populate the venv table view.
+        """Populate the venv table view.
         """
         self.model_venv_table.setRowCount(0)
 
-        for info in get_active_dir():
+        for info in get_data.get_active_dir():
             self.model_venv_table.insertRow(0)
             for i, text in enumerate((
-                info.venv_name,
-                info.venv_version,
-                info.system_site_packages,
-                info.is_on_system
+                    info.venv_name,
+                    info.venv_version,
+                    info.site_packages,
+                    info.is_installed
             )):
                 self.model_venv_table.setItem(0, i, QStandardItem(text))
-            print(f"[VENV]: {info}")
 
 
     def update_label(self):
@@ -567,11 +557,11 @@ class MainWindow(QMainWindow):
         )
         with_folder = (
             f'<span style="font-size: 13pt; color: #0059ff;">\
-                {get_active_dir_str()}\
+                {get_data.get_active_dir_str()}\
             </span>'
         )
 
-        if get_active_dir_str() != "":
+        if get_data.get_active_dir_str() != "":
             self.venv_table_label.setText(f"{head}{with_folder}")
         else:
             self.venv_table_label.setText(f"{head}{no_folder}")
@@ -584,7 +574,7 @@ class MainWindow(QMainWindow):
         """
         directory = QFileDialog.getExistingDirectory(
             self,
-            "Open directory containing virtual environments"
+            "Open a folder containing virtual environments"
         )
         self.directory_line.setText(directory)
 
@@ -595,27 +585,54 @@ class MainWindow(QMainWindow):
             if os.path.exists(active_file):
                 with open(active_file, "w") as f:
                     f.write(active_dir)
-                    print(
-                        "[INFO]: Setting active dir to "
-                        f"'{active_dir}'"
-                    )
                 self.pop_venv_table()
                 self.update_label()
 
 
     def search_pypi(self):
-        """
-        Search the Python Package Index.
+        """Search the Python Package Index.
         """
         pass
 
 
+def with_args():
+    """Execute with command-line arguments.
+    """
+    # get full command-line arguments
+    full_cmd_arguments = sys.argv
+
+    # ignore the first
+    argument_list = full_cmd_arguments[1:]
+
+    # tell getopts() the parameters
+    short_options = "V"
+    long_options = ["version"]
+
+    # use try-except to cover errors
+    try:
+        arguments, values = getopt.getopt(
+            argument_list, short_options, long_options
+        )
+    except getopt.error as e:
+        # print error message and return error code
+        print(str(e))
+        sys.exit(2)
+
+    for arg, val in arguments:
+        if arg in ("-V", "--version"):
+            # print version, then exit
+            print(f"VenviPy {get_data.__version__}")
+            sys.exit(0)
+
+
 def main():
+    with_args()
+
     app = QApplication(sys.argv)
     os.system("clear")
 
     main_window = MainWindow()
-    get_python_installs()
+    get_data.get_python_installs()
     main_window.pop_interpreter_table()
     main_window.venv_wizard.basic_settings.pop_combo_box()
     main_window.pop_venv_table()
